==> jc-1.4.0.tar.gz: polyglot/visit/FlowGraph__24ListKey.h <==
// public class polyglot.visit.FlowGraph$ListKey

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 612db14fa8b6ef9f polyglot_visit_FlowGraph__24ListKey

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_visit_FlowGraph__24ListKey_H_
#define _JC_polyglot_visit_FlowGraph__24ListKey_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;

// Typedefs
typedef struct _jc_polyglot_visit_FlowGraph__24ListKey$sub_refs	_jc_polyglot_visit_FlowGraph__24ListKey$sub_refs;
typedef struct _jc_polyglot_visit_FlowGraph__24ListKey$sub_nonrefs	_jc_polyglot_visit_FlowGraph__24ListKey$sub_nonrefs;
typedef struct _jc_polyglot_visit_FlowGraph__24ListKey$refs	_jc_polyglot_visit_FlowGraph__24ListKey$refs;
typedef struct _jc_polyglot_visit_FlowGraph__24ListKey$nonrefs	_jc_polyglot_visit_FlowGraph__24ListKey$nonrefs;
typedef struct _jc_polyglot_visit_FlowGraph__24ListKey$object	_jc_polyglot_visit_FlowGraph__24ListKey$object;

typedef const struct _jc_polyglot_visit_FlowGraph__24ListKey$vmethods	_jc_polyglot_visit_FlowGraph__24ListKey$vmethods;
typedef const struct _jc_polyglot_visit_FlowGraph__24ListKey$vtable	_jc_polyglot_visit_FlowGraph__24ListKey$vtable;
typedef const struct _jc_polyglot_visit_FlowGraph__24ListKey$vtype	_jc_polyglot_visit_FlowGraph__24ListKey$vtype;

// Constructors
extern void _jc_polyglot_visit_FlowGraph__24ListKey$method$_init$dd8ff073a2c7f994(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24ListKey$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_polyglot_visit_FlowGraph__24ListKey$method$equals$8a15e0625571c581(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24ListKey$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_polyglot_visit_FlowGraph__24ListKey$method$hashCode$53152098849316df(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24ListKey$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_FlowGraph__24ListKey$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_polyglot_visit_FlowGraph__24ListKey$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_polyglot_visit_FlowGraph__24ListKey$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24ListKey$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24ListKey$object *);
};

// Vtable
struct _jc_polyglot_visit_FlowGraph__24ListKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_FlowGraph__24ListKey$vmethods	polyglot_visit_FlowGraph__24ListKey;
};

// Vtype
struct _jc_polyglot_visit_FlowGraph__24ListKey$vtype {
	_jc_type			type;
	_jc_polyglot_visit_FlowGraph__24ListKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_FlowGraph__24ListKey$sub_refs {
	struct _jc_object	*list;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_FlowGraph__24ListKey$refs {
    _jc_polyglot_visit_FlowGraph__24ListKey$sub_refs	polyglot_visit_FlowGraph__24ListKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_FlowGraph__24ListKey$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_FlowGraph__24ListKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_FlowGraph__24ListKey$sub_nonrefs	polyglot_visit_FlowGraph__24ListKey;
};

// Object instance structure
struct _jc_polyglot_visit_FlowGraph__24ListKey$object {
	_jc_polyglot_visit_FlowGraph__24ListKey$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_FlowGraph__24ListKey$vtype	*vtype;
	_jc_polyglot_visit_FlowGraph__24ListKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_FlowGraph__24ListKey$vtype _jc_polyglot_visit_FlowGraph__24ListKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_FlowGraph__24ListKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_FlowGraph__24ListKey$class_object;

#endif	/* _JC_polyglot_visit_FlowGraph__24ListKey_H_ */

==> jc-1.4.6.tar.gz: polyglot/visit/FlowGraph__24ListKey.h <==
// public class polyglot.visit.FlowGraph$ListKey

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 612db14fa8b6ef9f polyglot_visit_FlowGraph__24ListKey

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_visit_FlowGraph__24ListKey_H_
#define _JC_polyglot_visit_FlowGraph__24ListKey_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;

// Typedefs
typedef struct _jc_polyglot_visit_FlowGraph__24ListKey$sub_refs	_jc_polyglot_visit_FlowGraph__24ListKey$sub_refs;
typedef struct _jc_polyglot_visit_FlowGraph__24ListKey$sub_nonrefs	_jc_polyglot_visit_FlowGraph__24ListKey$sub_nonrefs;
typedef struct _jc_polyglot_visit_FlowGraph__24ListKey$refs	_jc_polyglot_visit_FlowGraph__24ListKey$refs;
typedef struct _jc_polyglot_visit_FlowGraph__24ListKey$nonrefs	_jc_polyglot_visit_FlowGraph__24ListKey$nonrefs;
typedef struct _jc_polyglot_visit_FlowGraph__24ListKey$object	_jc_polyglot_visit_FlowGraph__24ListKey$object;

typedef const struct _jc_polyglot_visit_FlowGraph__24ListKey$vmethods	_jc_polyglot_visit_FlowGraph__24ListKey$vmethods;
typedef const struct _jc_polyglot_visit_FlowGraph__24ListKey$vtable	_jc_polyglot_visit_FlowGraph__24ListKey$vtable;
typedef const struct _jc_polyglot_visit_FlowGraph__24ListKey$vtype	_jc_polyglot_visit_FlowGraph__24ListKey$vtype;

// Constructors
extern void _jc_polyglot_visit_FlowGraph__24ListKey$method$_init$dd8ff073a2c7f994(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24ListKey$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_polyglot_visit_FlowGraph__24ListKey$method$equals$8a15e0625571c581(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24ListKey$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_polyglot_visit_FlowGraph__24ListKey$method$hashCode$53152098849316df(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24ListKey$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_FlowGraph__24ListKey$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_polyglot_visit_FlowGraph__24ListKey$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_polyglot_visit_FlowGraph__24ListKey$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24ListKey$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_polyglot_visit_FlowGraph__24ListKey$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_visit_FlowGraph__24ListKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_FlowGraph__24ListKey$vmethods	polyglot_visit_FlowGraph__24ListKey;
};

// Vtype
struct _jc_polyglot_visit_FlowGraph__24ListKey$vtype {
	_jc_type			type;
	_jc_polyglot_visit_FlowGraph__24ListKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_FlowGraph__24ListKey$sub_refs {
	struct _jc_object	*list;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_FlowGraph__24ListKey$refs {
    _jc_polyglot_visit_FlowGraph__24ListKey$sub_refs	polyglot_visit_FlowGraph__24ListKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_FlowGraph__24ListKey$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_FlowGraph__24ListKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_FlowGraph__24ListKey$sub_nonrefs	polyglot_visit_FlowGraph__24ListKey;
};

// Object instance structure
struct _jc_polyglot_visit_FlowGraph__24ListKey$object {
	_jc_polyglot_visit_FlowGraph__24ListKey$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_FlowGraph__24ListKey$vtype	*vtype;
	_jc_polyglot_visit_FlowGraph__24ListKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_FlowGraph__24ListKey$vtype _jc_polyglot_visit_FlowGraph__24ListKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_FlowGraph__24ListKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_FlowGraph__24ListKey$class_object;

#endif	/* _JC_polyglot_visit_FlowGraph__24ListKey_H_ */
